#! /bin/bash
#
# Creates top-level worksheet index file, using data in ../files/<config>.
# LaTeX-specific preamble section may be removed harmlessly.

OUTFILE="index.html"
CONFIGFILE="${1:-config}"

declare -r WCOLUMNS=4 # number of columns in table of worksheet links
function pad_num () {
    if [ $1 -lt 10 ]; then
	echo "0$1"
    else
	echo "$1"
    fi
}

# Write output file
cat <<EOF > "$OUTFILE"
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">

<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1" />
<meta http-equiv="Content-Style-Type" content="text/css" />
EOF

echo "<meta http-equiv=\"last-modified\" content=\"$(date --rfc-2822)\" />" >> "$OUTFILE"

cat <<EOF >> "$OUTFILE"
<meta name="description" content="LaTeX training worksheets" />
<meta name="robots" content="noindex, nofollow" />

<title>
LaTeX Formatting Worksheets
</title>

<link rel="stylesheet" type="text/css" href="./css/workbook.css" />
</head>

<body>
<div style="max-width:640px; text-align:justify; margin-left:auto; margin-right: auto;">

<h1>
LaTeX Formatting Worksheets
</h1>

<h2>Instructions</h2>

<p>
These self-study worksheets, for use in a web browser, are part of the
<a href="http://mathcs.holycross.edu/~ahwang/pgdp/dptest/index.html">
<b>LaTeX formatting documentation and training materials</b></a>
created for producers of public-domain mathematical ebooks (such as at
<a href="http://www.pgdp.net"><b>Distributed Proofreaders</b></a>,
a.k.a.&nbsp;DP). You may work with them online or
<a href="http://mathcs.holycross.edu/~ahwang/pgdp/dptest/doc/latex_worksheets/LaTeX_Worksheets.zip">
<b>download</b>
</a>
them to your own computer for offline use.
</p>

<p>
Each worksheet presents you with the scan of a page from a math book
and proofread text, similar to output from the DP&nbsp;proofing rounds,
just as if you were working in the F1&nbsp;round at&nbsp;DP. At any time
while working you may view:
</p>
<ul>
<li> The page scan and your (editable) current work. Initially, your
current work is the proofread text from the DP&nbsp;proofing
rounds.</li>

<li> The page scan and (non-editable) formatted text, i.e., the
&ldquo;answer key&rdquo; to the worksheet.</li>

<li> A color-coded diff between your current work and the answer key,
i.e., the &ldquo;corrections&rdquo; to your current work.
<!--In the
diffs, the blue highlighting with strikethrough shows text that would
need deleting, and gold highlighting with underline shows text that
would need inserting, in order to transform your current work into
the &ldquo;answer&rdquo;.--></li>
</ul>

<p>
<b>Any changes you make to your current work will be saved until you
visit another worksheet or close your browser.</b> You may look at the
answer or &ldquo;check your work&rdquo; incrementally as many times as
you like, so long as you do not open a new worksheet in the same
browser tab.
</p>

<p>
Three <b>navigation links</b> are visible near the upper left-hand
corner of each worksheet. The navigation links are black triangles in
rectangular frames. Each link takes you to a new page, and <b>erases
any changes you have made to the proofread text</b>.
</p>
<ul>
  <li> <img src="./images/arrow_prev.png" alt="Previous" style="height:2ex;" /> takes you to
    the preceding worksheet.</li>

  <li> <img src="./images/arrow_next.png" alt="Next" style="height:2ex;" /> takes you to
  the next worksheet. The worksheets are linked circularly, i.e., the
  first worksheet &ldquo;follows&rdquo; the last worksheet.</li>

  <li> <img src="./images/arrow_up.png" alt="Index" style="height:2ex;" /> returns you to
  this index page.</li>
</ul>

<!-- TO DO: Implement button to generate compilable page code-->
<p>
Two <b>action buttons</b> are visible near the upper right-hand corner
of each worksheet. Recall that each worksheet has three possible
&ldquo;views&rdquo;: your current work, the correctly formatted text
(answer key), and the diff between your current work and the answer
(the corrections). In each view, the two buttons will take you to the
<b>other two views</b>. These buttons change their functions according
to what you are currently viewing, but if you are viewing your current
work, clicking either button twice returns you to your current work.
</p>

<!--You can now edit the Proofing round text just as
you would in&nbsp;F1. If you
are unsure how to tackle any part of the text, you can click on the
"Formatter Text" button. In place of your text, you will then see an
example of how the text was previously formatted by an experienced
LaTeX formatter. Just click the Proofer Text button to return to your
edits. Also, at any point you can see the difference between your
version and the experienced Formatter's version by clicking the Show
Diff button. In the diffs, the blue highlighting with strikethrough
shows text that would need deleting, and gold highlighting with
underline shows text that would need to be added, in order to change
your text to be the same as the Formatter Text.-->

<p>
<b>Not all diffs are errors.</b> Do watch for missed markup including
&ldquo;essential&rdquo; ties, and for proper, semantic coding of
theorems, definitions, exercises, chapters, and other sectional units.
(Ties such as <code>pg.~42</code> and <code>Vol.~V</code> are
essential, while <code>page~42</code>, <code>Volume~V</code>, or
<code>\$a\$~and~\$b\$</code> are not. The answer keys contain only
essential ties.)
</p>

<p>
Don't worry about differences in the source code layout of displayed
mathematics that don't affect the typographical output. (The volunteer
who created the answer keys generally coded in order to make the
result easy to read mathematically.)
</p>

<p>
Small text (the <code>Remark</code> environment) and italicized
passages (the <code>Thm</code> environment) should be noted and coded
semantically.  Use an ordinary <code>itemize</code> environment and
<code>\item</code> commands for numbered exercises. Supply the
exercise number as an optional argument, e.g.,
<code>\item[42.]</code>; do not rely on LaTeX's auto-numbering.
</p>

<p>
Use an <code>array</code> environment and explicit braces to handle
matrices; this gives the post-processor more flexibility to align the
matrix extries than LaTeX's <code>matrix</code> environments.
</p>
</div>

<h2>Worksheets</h2>

<table style="border: 1px; width: 100%;">
EOF

IDX=0
NEEDCLOSE=false

cat "./files/$CONFIGFILE" | grep -v "#" | while read FILEROOT PAGETITLE
do
    if [ $((IDX % $WCOLUMNS)) -eq 0 ]; then
	echo "<tr>" >> "$OUTFILE";
	needclose=true;
    fi

    let IDX++
    echo "<td style=\"text-align: center;\"> <a href=\"./worksheets/Worksheet$(pad_num $IDX).html\"><b>Worksheet $(pad_num $IDX): $PAGETITLE</b></a></td>" >> "$OUTFILE"

    if [ $((IDX % $WCOLUMNS)) -eq 0 ]; then
	echo "</tr>" >> "$OUTFILE";
	needclose=false;
    fi
done
if [ $needclose=true ]; then
    echo "</tr>" >> "$OUTFILE"
fi
cat <<EOF >> "$OUTFILE"
</table>

<hr />

<h2>Preamble Interface</h2>

<p>
Latin-1 characters in the text, including accented letters and the
symbols
<code></code>, <code></code>, <code></code>, <code></code>,
<code></code>, and&nbsp;<code></code>, should be retained; <b>do not
code these using LaTeX macros</b>.
</p>

<p>
Where possible, pages should be coded using the preamble interface
below. (Note: This code merely describes the macro call syntax; it is not
working preamble code.)
</p>

<pre>
\Chapter{}{} % e.g. \Chapter{I.}{Introduction.}
\Section{}   %      \Section{Preliminary Theorems.}
\Subsection{}%      \Subsection{Notes.}
\Par{}       %      \Par{1. Rational numbers.} (Boldface, run-in heading)

% Semantic units with (possibly numbered) run-in headings
\begin{Theorem}...\end{Theorem}
\begin{Theorem}[42.]...\end{Theorem}
% Similarly for Corollary, Definition, Lemma

\Proof % Start of proof

% Semantic units signified by a change of typeface
\begin{Thm} ... \end{Thm} % Italicized assertion (possibly mid-paragraph)
\begin{Remark} ... \end{Remark} % Smaller text of a remark

\begin{Exercises} ... \end{Exercises} % Numbered lists of exercises

\First{} % Small-capped first word of chapter
\Ie, \Eg, \ie, \eg % Latin abbreviations

\dd % Partial derivative symbol
\Tag{(42')} % Equation number
\Eq{(96)}   % Reference to equation number

\DPnote{** note}
\DPtypo{txet}{text}
</pre>
<hr />
<p>
<a href="http://validator.w3.org/check?uri=referer">
  <img src="http://www.w3.org/Icons/valid-xhtml10" alt="Valid XHTML 1.0 Strict" height="31" width="88" />
</a>
<a href="http://jigsaw.w3.org/css-validator/check/referer">
    <img style="border:0;width:88px;height:31px"
        src="http://jigsaw.w3.org/css-validator/images/vcss-blue"
        alt="Valid CSS!" />
</a>
</p>
</body>
</html>
EOF

exit 0
